package com.huashe.park.core.service;

import com.huashe.park.domain.entity.ProjectInfo;

import java.util.List;

/**
 * 工程信息Service接口
 * 
 * @author ruoyi
 * @date 2025-02-14
 */
public interface IProjectInfoService 
{
    /**
     * 查询工程信息
     * 
     * @param id 工程信息主键
     * @return 工程信息
     */
    public ProjectInfo selectProjectInfoById(Long id);

    /**
     * 查询工程信息列表
     * 
     * @param projectInfo 工程信息
     * @return 工程信息集合
     */
    public List<ProjectInfo> selectProjectInfoList(ProjectInfo projectInfo);

    /**
     * 新增工程信息
     * 
     * @param projectInfo 工程信息
     * @return 结果
     */
    public int insertProjectInfo(ProjectInfo projectInfo);

    /**
     * 修改工程信息
     * 
     * @param projectInfo 工程信息
     * @return 结果
     */
    public int updateProjectInfo(ProjectInfo projectInfo);

    /**
     * 批量删除工程信息
     * 
     * @param ids 需要删除的工程信息主键集合
     * @return 结果
     */
    public int deleteProjectInfoByIds(Long[] ids);

    /**
     * 删除工程信息信息
     * 
     * @param id 工程信息主键
     * @return 结果
     */
    public int deleteProjectInfoById(Long id);
}
